==> camunda-webapp-webjar-7.10.0.jar: META-INF/resources/webjars/camunda/app/cockpit/scripts/config.js <==
window.camCockpitConf = {
  // // custom libraries and scripts loading and initialization,
  // // see: http://docs.camunda.org/guides/user-guide/#tasklist-customizing-custom-scripts
  // customScripts: {
  //   // AngularJS module names
  //   ngDeps: ['ui.bootstrap'],
  //   // RequireJS configuration for a complete configuration documentation see:
  //   // http://requirejs.org/docs/api.html#config
  //   deps: ['jquery', 'custom-ui'],
  //   paths: {
  //     // if you have a folder called `custom-ui` (in the `cockpit` folder)
  //     // with a file called `scripts.js` in it and defining the `custom-ui` AMD module
  //     'custom-ui': 'custom-ui/scripts'
  //   }
  // },
  // historicActivityInstanceMetrics: {
  //   adjustablePeriod: true,
  //   //select from the default time period: today, week, month, complete
  //   period: {
  //     unit: 'week'
  //   }
  // },
  // set if a user can change the default or no
  // userCanChangePeriod: true/false
  // },
  // 'locales': {
  //   'availableLocales': ['en', 'de'],
  //   'fallbackLocale': 'en'
  // },
  // skipCustomListeners: {
  //   default: true,
  //   hidden: false
  // },
  // 'batchOperation' : {
  //   // select mode of query for process instances or decision instances
  //   // possible values: filter, search
  //   'mode': 'filter'
  // },
  // bpmnJs: {
  //   moddleExtensions: {
  //     // if you have a folder called 'my-custom-moddle' (in the 'cockpit' folder)
  //     // with a file called 'camunda.json' in it defining the 'camunda' moddle extension
  //     camunda: 'my-custom-moddle/camunda'
  //   },
  //   additionalModules: {
  //     // if you have a folder called 'my-custom-module' (in the 'cockpit' folder)
  //     // with a file called 'module.js' in it defining the 'my-custom-module' AMD module
  //     myCustomModule: 'my-custom-module/module'
  //   }
  // }
};

==> camunda-webapp-webjar-7.11.0.jar: META-INF/resources/webjars/camunda/app/cockpit/scripts/config.js <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

window.camCockpitConf = {
  // // custom libraries and scripts loading and initialization,
  // // see: http://docs.camunda.org/guides/user-guide/#tasklist-customizing-custom-scripts
  // customScripts: {
  //   // AngularJS module names
  //   ngDeps: ['ui.bootstrap'],
  //   // RequireJS configuration for a complete configuration documentation see:
  //   // http://requirejs.org/docs/api.html#config
  //   deps: ['jquery', 'custom-ui'],
  //   paths: {
  //     // if you have a folder called `custom-ui` (in the `cockpit` folder)
  //     // with a file called `scripts.js` in it and defining the `custom-ui` AMD module
  //     'custom-ui': 'custom-ui/scripts'
  //   }
  // },
  // historicActivityInstanceMetrics: {
  //   adjustablePeriod: true,
  //   //select from the default time period: today, week, month, complete
  //   period: {
  //     unit: 'week'
  //   }
  // },
  // set if a user can change the default or no
  // userCanChangePeriod: true/false
  // },
  // 'locales': {
  //   'availableLocales': ['en', 'de'],
  //   'fallbackLocale': 'en'
  // },
  // skipCustomListeners: {
  //   default: true,
  //   hidden: false
  // },
  // skipIoMappings: {
  //   default: true,
  //   hidden: false
  // },
  // 'batchOperation' : {
  //   // select mode of query for process instances or decision instances
  //   // possible values: filter, search
  //   'mode': 'filter'
  // },
  // bpmnJs: {
  //   moddleExtensions: {
  //     // if you have a folder called 'my-custom-moddle' (in the 'cockpit' folder)
  //     // with a file called 'camunda.json' in it defining the 'camunda' moddle extension
  //     camunda: 'my-custom-moddle/camunda'
  //   },
  //   additionalModules: {
  //     // if you have a folder called 'my-custom-module' (in the 'cockpit' folder)
  //     // with a file called 'module.js' in it defining the 'my-custom-module' AMD module
  //     myCustomModule: 'my-custom-module/module'
  //   }
  // },
  // defaultFilter: {
  //   historicProcessDefinitionInstancesSearch: {
  //     lastDays: 5,
  //     event: 'started'
  //   }
  // }
};
